# Changelog

## 2.0.2

- Fix relative link in README

## 2,0,1

- Add Python 3.11 support

## 2.0.0

- Added ImageJ plugin
- Added CellProfiler plugin
- Added napari plugin
- Added handling of masked arrays.
- Added API module.
- Added type annotations.

## 1.0.1

- Fixed 1D implementation.

## 1.0.0

- Initial release of SMO.
